/**
  *  \file client/dialogs/objselect.cc
  *
  *  (c) 2001-2024 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "client/dialogs/objselect.h"
#include "ui/widgets/button.h"
#include "ui/commands.h"
#include "client/widgets/helpwidget.h"
#include "gfx/palette.h"
#include "ui/layout.h"
#include "util/nls.h"
#include "client/widgets/objcontrol.h"
#include "client/tiles/objheader.h"
#include "ui/widgets/quit.h"

WObjectSelectionDialog::WObjectSelectionDialog(const string_t title,
                                                 const string_t helpId,
                                                 GObjectSelection& selection)
    : UIWindow(title, UIWindow::BLUE_WINDOW, COLOR_GRAY),
      content(h.add(new UIGroup(UIVBoxLayout::instance5)))
{
    buildDialog(helpId, selection);
}

void
WObjectSelectionDialog::buildDialog(const string_t& helpId, GObjectSelection& selection)
{
    setLayout(UIVBoxLayout::instance5);

    UIGroup& buttons = h.add(new UIGroup(UIHBoxLayout::instance5));
    buttons.add(h.add(new UIButton(cm_Enter, _("ENTER - View"), SDLK_RETURN)).addStop());
    buttons.add(h.add(new UIButton(cm_Escape, _("ESC"),         SDLK_ESCAPE)).addStop());
    buttons.add(h.add(new UISpacer()));
    buttons.add(h.add(new UIButton("H", 'H')));

    add(h.add(new WObjectSelectionHeaderTile(selection)));
    add(content);
    add(buttons);
    add(h.add(new WObjectSelectionControl(selection)));
    add(h.add(new WHelpWidget(helpId)));
    add(h.add(new UIQuit(cm_Escape)));
}

void
WObjectSelectionDialog::addWidget(UIBaseWidget& w)
{
    content.add(w);
}
