/**
  *  \file client/remote.h
  *
  *  (c) 2001-2024 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_CLIENT_REMOTE_H
#define PCC_V2_CLIENT_REMOTE_H

#include "client/wcolorframe.h"

class GCommandContainer;
class GShip;

/** Remote control state summary. */
enum TRemoteControlSetting {
    rc_Forbidden,                   ///< Own ship, RC disallowed.
    rc_Normal,                      ///< Own ship, normal.
    rc_RemoteControlled,            ///< Enemy ship, we control it.
    rc_Applying,                    ///< Enemy ship, control requested.
    rc_Dropping,                    ///< Enemy ship, control being given back.
    rc_Other,                       ///< Enemy ship, normal (we don't control).
    rc_OtherForbidden,              ///< Enemy ship, RC disallowed.
    rc_OurRemoteControlled          ///< Own ship under foreign control
};

/** Remote control verbs. Note that the order is important here, each
    verb can be negated by '^1'. In addition, this is used as index
    into a number of tables. */
enum TRemoteControlVerb {
    rcv_Allow   = 0,
    rcv_Forbid  = 1,
    rcv_Drop    = 2,
    rcv_Control = 3
};

TRemoteControlSetting getOldRemoteControlState(const GShip& sh);
TRemoteControlSetting getNewRemoteControlState(const GShip& sh, GCommandContainer& cmds);
TFrameColor           getRemoteControlColor(TRemoteControlSetting v);

void doRemoteControl(GShip& sh, GCommandContainer& cmds);
bool setRemoteControl(GShip& sh, GCommandContainer& cmds, TRemoteControlVerb verb);

#endif
