/**
  *  \file game/pref.cc
  *  \brief User Preferences
  *
  *  This file contains the user preferences (in contrast to
  *  game/config.cc, which contains the game configuration). This
  *  must be in game/, because some game code depends on it.
  *
  *  (c) 2001-2024 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "game/pref.h"

static ValueEnumParser parse_chartWheel("zoom,browse,page");

GUserPreferences::GUserPreferences()
    : CollapseOldMessages(*this, "Messages.CollapseOld", ValueBoolParser::instance),
      RewrapMessages(*this, "Messages.RewrapInbox", ValueBoolParser::instance),
      InstantBattleResult(*this, "VCR.InstantResult", ValueBoolParser::instance),
      AutoWarp(*this, "Ship.AutoWarp", ValueBoolParser::instance),

      Sound16Bits(*this, "Sound.16Bits", ValueBoolParser::instance),
      SoundEnabled(*this, "Sound.Enabled", ValueBoolParser::instance),
      SoundFrequency(*this, "Sound.Frequency", ValueIntParser::instance),
      SoundHeadphone(*this, "Sound.Headphone", ValueBoolParser::instance),
      SoundReverse(*this, "Sound.Reverse", ValueBoolParser::instance),
      SoundStereo(*this, "Sound.Stereo", ValueBoolParser::instance),
      ChartAnimThreshold(*this, "Chart.AnimThreshold", ValueIntParser::instance),
      ChartMouseStickiness(*this, "Chart.MouseStickiness", ValueIntParser::instance),
      ChartScannerWarpWells(*this, "Chart.Scanner.WarpWells", ValueBoolParser::instance),
      ChartWheel(*this, "Chart.Wheel", parse_chartWheel),
      TeamAutoSync(*this, "Team.AutoSync", ValueBoolParser::instance),
      DisplayThousandSep(*this, "Display.ThousandsSep", ValueBoolParser::instance),
      DisplayClans(*this, "Display.Clans", ValueBoolParser::instance),
      ExportShipFields(*this, "Export.ShipFields"),
      ExportPlanetFields(*this, "Export.PlanetFields")
{
    assignDefaults();
}

void
GUserPreferences::assignDefaults()
{
    CollapseOldMessages.set(false);
    RewrapMessages.set(true);
    InstantBattleResult.set(true);
    AutoWarp.set(true);

    Sound16Bits.set(true);
    SoundEnabled.set(true);
    SoundFrequency.set(22050);
    SoundHeadphone.set(false);
    SoundReverse.set(false);
    SoundStereo.set(true);

    ChartAnimThreshold.set(11);
    ChartMouseStickiness.set(5);
    ChartScannerWarpWells.set(0);

    TeamAutoSync.set(1);

    DisplayThousandSep.set(1);
    DisplayClans.set(0);

    ExportShipFields.set("Id@5,Name@20");
    ExportPlanetFields.set("Id@5,Name@20");
}

GUserPreferences&
getUserPreferences()
{
    static GUserPreferences user_pref;
    return user_pref;
}
