/**
  *  \file int/if/playerif.h
  *  \brief Interpreter Game Interface: Player Properties
  *
  *  (c) 2001-2024 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_INT_IF_PLAYERIF_H
#define PCC_V2_INT_IF_PLAYERIF_H

#include "int/context.h"

class IntValue;
class IntArgBlock;

IntValue*   IFPlayerGet(IntArgBlock& args);
IntContext* IFPlayerMake();
int32_t     IFPlayerDim(int32_t dim);

/** Player context. */
class IntPlayerContext : public IntContext {
    int pid;
 public:
    IntPlayerContext(int pid);
    ~IntPlayerContext();

    // IntContext:
    int32_t   lookup(const IntNameQuery& name);
    void      set(int32_t index, IntValue* value);
    IntValue* get(int32_t index);
    bool      next();
    IntContext* clone();
    GObject*  getObject();
    string_t  toString(bool readable);
    void      store(IntTagNode& sv, Stream& aux);
    void      enumProperties(IntPropertyAcceptor& acceptor);
};

/** Player properties. */
enum IntPlayerProperty {
    iplAdjName,
    iplFullName,
    iplId,
    iplMission,
    iplPBPs,
    iplRaceId,
    iplTeam,
    iplShortName,
    iplScoreBases,
    iplScorePlanets,
    iplScoreShips,
    iplScore,
    iplScoreCapital,
    iplScoreFreighters,
    iplTotalShips,
    iplTotalFreighters,
    iplTotalCapital
};

IntValue* getPlayerProperty(int pid, IntPlayerProperty ipl);

#endif
