#!/usr/bin/perl -w
#
#  PCC2 Help Link Checker
#
#  Invoke this, giving it the PCC2 help files as parameter:
#    perl scripts/linkcheck.pl resource/pcc2*xml
#
#  This will produce
#  - an error report (undefined and unused links) on stderr
#  - link/text cross reference (to see which links might point to the wrong target) on stdout
#

my $text = join('', <>);

# $data{$link}{def}         = number of definitions
# $data{$link}{use}         = number of uses
# $data{$link}{text}{$text} = number of links to this page with the given text
my %data;
my $pages = 0;
my $links = 0;
while ($text =~ m|<page id="(.*?)">|g) {
    $data{$1}{def}++;
    ++$pages;
}
while ($text =~ m|<a href="(.*?)">(.*?)</a>|smg) {
    $data{$1}{use}++;
    $data{$1}{text}{$2}++;
    ++$links;
}


foreach (sort keys %data) {
    if (!$data{$_}{def}) {
        print STDERR "ERROR: '$_' is not defined\n";
    }
    if (!$data{$_}{use}) {
        print STDERR "ERROR: '$_' is not used\n";
    }
}

print "$pages pages, $links links\n";
foreach my $k (sort keys %data) {
    my @k = keys(%{$data{$k}{text}});
    if (@k > 1 || (@k == 1 && $data{$k}{use} <= 2)) {
        # We show texts for links that either have multiple different texts,
        # or only one text appearing very rarely. This weeds out the majority
        # of links in the script manual, which have identical text and occur
        # frequently.
        print "$k\n";
        foreach my $t (sort keys %{$data{$k}{text}}) {
            printf "%10d %s\n", $data{$k}{text}{$t}, $t;
        }
    }
}
